@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Node;
-$ExtUtils::Builder::Node::VERSION = '0.012';
+$ExtUtils::Builder::Node::VERSION = '0.013';
 use strict;
 use warnings;
 
@@ -10,9 +10,9 @@ use Carp 'croak';
 sub new {
 	my ($class, %args) = @_;
 	croak('Attribute target is not defined') if not $args{target};
-	$args{actions} = [ map { $_->flatten } @{ $args{actions} || [] } ];
-	$args{dependencies} ||= [];
-	$args{type} ||= delete $args{phony} ? 'phony' : 'file';
+	$args{actions} = [ map { $_->flatten } @{ $args{actions} // [] } ];
+	$args{dependencies} //= [];
+	$args{type} //= delete $args{phony} ? 'phony' : 'file';
 	return $class->SUPER::new(%args);
 }
 
@@ -68,7 +68,7 @@ ExtUtils::Builder::Node - An ExtUtils::Builder Node
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
